@@ -1,8 +1,14 @@
 # https://setuptools.pypa.io/en/latest/pkg_resources.html#workingset-objects
 def fix_dependencies():
     import __main__
-    __main__.__requires__ = ['jetto_tools>=1.8.8']
-    __main__.__requires__ = ['jinja2>=3.0.0']
+    __main__.__requires__ = [
+        'jetto_tools>=1.8.8',
+        'pydantic!=1.10.3',
+        'pydantic!=1.10.4',
+        'pydantic!=1.10.5',
+        'scipy>=1.09',
+        'jinja2>=3.0.0',
+    ]
     import pkg_resources  # noqa
 
 
@@ -10,7 +16,7 @@ fix_dependencies()
 
 __author__ = 'Stef Smeets'
 __email__ = 's.smeets@esciencecenter.nl'
-__version__ = '1.5.0'
+__version__ = '1.6.2'
 
 import logging  # noqa
 import warnings  # noqa
