@@ -80,8 +80,9 @@ def logfile_option(f):
                         group='Common options')(f)
 
 
-all_options = (logfile_option, debug_option, config_option, quiet_option,
-               dry_run_option, yes_option)
+logging_options = (logfile_option, debug_option)
+all_options = (*logging_options, config_option, quiet_option, dry_run_option,
+               yes_option)
 
 
 def handles_option(f):
@@ -197,7 +198,7 @@ def common_options(*options):
     return decorator
 
 
-def cli_entry():
+def cli_entry(**kwargs):
     from duqtools import fix_dependencies
     fix_dependencies()
     cli()
@@ -219,8 +220,7 @@ def cli(**kwargs):
               help='Path to write config to (default=duqtools.yaml).',
               default='duqtools.yaml')
 @click.option('--force', is_flag=True, help='Overwrite existing config.')
-@common_options(logfile_option, debug_option, quiet_option, dry_run_option,
-                yes_option)
+@common_options(*logging_options, quiet_option, dry_run_option, yes_option)
 def cli_init(**kwargs):
     """Create a default config file."""
     from .init import init
@@ -231,6 +231,32 @@ def cli_init(**kwargs):
             exit(e)
 
 
+@cli.command('setup')
+@click.option(
+    '-r',
+    '--run_name',
+    type=str,
+    help='Name of the run.',
+    default='duqtools',
+)
+@click.option(
+    '-t',
+    '--template',
+    'template_file',
+    type=click.Path(exists=True),
+    help='Template duqtools.yaml',
+    default='duqtools.template.yaml',
+)
+@click.option('-h', '--handle', 'handle', type=str, help='IMAS data handle.')
+@click.option('--force', is_flag=True, help='Overwrite existing config')
+@common_options(*logging_options, yes_option)
+def cli_setup(**kwargs):
+    """Template substitution for duqtools config."""
+    from .setup import setup
+    with op_queue_context():
+        setup(**kwargs)
+
+
 @cli.command('create', cls=GroupCmd)
 @click.option('--force',
               is_flag=True,
@@ -278,6 +304,12 @@ def cli_recreate(**kwargs):
               default=tuple(),
               type=Path,
               help='Case to re-submit, can be specified multiple times')
+@click.option('-s',
+              '--status',
+              'status_filter',
+              type=str,
+              multiple=True,
+              help='Only submit jobs with this status.')
 @common_options(*all_options)
 def cli_submit(**kwargs):
     """Submit the UQ runs.
@@ -319,6 +351,7 @@ def cli_status(**kwargs):
               is_flag=True,
               help='Plot the errorbars (if present)')
 @datafile_option
+@common_options(*logging_options)
 def cli_plot(**kwargs):
     """Plot some IDS data.
 
@@ -385,7 +418,7 @@ def cli_yolo(ctx, **kwargs):
 
 
 @cli.command('dash', cls=GroupCmd)
-@common_options(*all_options)
+@common_options(*logging_options, quiet_option, dry_run_option, yes_option)
 def cli_dash(**kwargs):
     """Open dashboard for evaluating IDS data."""
     from .dash import dash
@@ -406,10 +439,6 @@ def cli_dash(**kwargs):
               required=True,
               type=str,
               help='IMAS location to store the result in')
-@click.option('--all',
-              'merge_all',
-              is_flag=True,
-              help='Try to merge all known variables.')
 @datafile_option
 @click.option('--force',
               is_flag=True,
@@ -440,6 +469,9 @@ def cli_merge(**kwargs):
 
     The `-t`, `-o` and `-h` options expect an IMAS path formatted as
     `user/db/shot/number` or `db/shot/number`.
+
+    By default, `duqduq merge` attempts to merge all known variables.
+    Use `--variable` to select which variables to merge.
     """
     from .merge import merge
     with op_queue_context():
@@ -458,5 +490,25 @@ def cli_list_variables(**kwargs):
     list_variables(**kwargs)
 
 
+@cli.command('version')
+def cli_version(**kwargs):
+    """Print the version and exit."""
+    import git
+
+    from duqtools import __version__
+
+    string = f'duqtools {__version__}'
+
+    try:
+        repo = git.Repo(Path(__file__), search_parent_directories=True)
+        sha = repo.head.object.hexsha
+    except OSError:
+        pass
+    else:
+        string += f' (rev: {sha})'
+
+    click.echo(string)
+
+
 if __name__ == '__main__':
     cli()
