@@ -1,8 +1,9 @@
-from ._config import cfg
+from ._config import Config, cfg
 from ._variables import lookup_vars, var_lookup
 
 __all__ = [
     'cfg',
-    'var_lookup',
+    'Config',
     'lookup_vars',
+    'var_lookup',
 ]
