@@ -5,8 +5,8 @@ import operator
 import os
 import sys
 from collections import UserDict
-from pathlib import Path
-from typing import Dict, Hashable, List, Optional, Sequence, Tuple, Union
+from pathlib import Path, PosixPath
+from typing import Hashable, Sequence
 
 from ..schema import IDSVariableModel
 from ..schema.variables import VariableConfigModel
@@ -25,6 +25,7 @@ LOCAL_DIR = Path('.').absolute()
 DUQTOOLS_DIR = 'duqtools'
 VAR_FILENAME = 'variables.yaml'
 VAR_FILENAME_GLOB = 'variables*.yaml'
+ERROR_SUFFIX = '_error_upper'
 
 
 class VarLookup(UserDict):
@@ -39,7 +40,17 @@ class VarLookup(UserDict):
     def __getitem__(self, key: str) -> IDSVariableModel:
         return self.data[self.normalize(key)]
 
-    def normalize(self, *keys: str) -> Union[str, Tuple[str, ...]]:
+    def error_upper(self, key: str) -> IDSVariableModel:
+        """Return error variable for given key.
+
+        i.e. `t_i_ave` -> `t_i_ave_error_upper`
+        """
+        var = self[key.removesuffix(ERROR_SUFFIX)].copy()
+        var.name += ERROR_SUFFIX
+        var.path += ERROR_SUFFIX
+        return var
+
+    def normalize(self, *keys: str) -> str | tuple[str, ...]:
         """Normalize variable names (remove `$`)."""
         keys = tuple(key.lstrip(self._prefix) for key in keys)
         if len(keys) == 1:
@@ -51,7 +62,7 @@ class VarLookup(UserDict):
         cmp = operator.ne if invert else operator.eq
         return VarLookup({k: v for k, v in self.items() if cmp(v.type, type)})
 
-    def groupby_type(self) -> Dict[Hashable, List[IDSVariableModel]]:
+    def groupby_type(self) -> dict[Hashable, list[IDSVariableModel]]:
         """Group entries by type."""
         grouped_ids_vars = groupby(self.values(), keyfunc=lambda var: var.type)
         return grouped_ids_vars
@@ -62,7 +73,7 @@ class VarLookup(UserDict):
 
         return VarLookup({k: v for k, v in ids_vars.items() if v.ids == ids})
 
-    def groupby_ids(self) -> Dict[Hashable, List[IDSVariableModel]]:
+    def groupby_ids(self) -> dict[Hashable, list[IDSVariableModel]]:
         """Group entries by IDS."""
         ids_vars = self.filter_type(self._ids_variable_key).values()
 
@@ -87,7 +98,7 @@ class VariableConfigLoader:
 
         return var_lookup
 
-    def get_config_path(self) -> Tuple[Path, ...]:
+    def get_config_path(self) -> tuple[Path, ...]:
         """Try to get the config file with variable definitions.
 
         Search order:
@@ -106,8 +117,7 @@ class VariableConfigLoader:
 
         return self._get_paths_fallback()
 
-    def _get_paths_from_environment_variable(
-            self) -> Optional[Tuple[Path, ...]]:
+    def _get_paths_from_environment_variable(self) -> tuple[Path, ...] | None:
         env = os.environ.get(VAR_ENV)
         if env:
             path = Path(env)
@@ -120,10 +130,10 @@ class VariableConfigLoader:
 
         return None
 
-    def _get_paths_local_directory(self) -> Optional[Tuple[Path, ...]]:
+    def _get_paths_local_directory(self) -> tuple[Path, ...] | None:
         return None  # Not implemented
 
-    def _get_paths_from_config_home(self) -> Optional[Tuple[Path, ...]]:
+    def _get_paths_from_config_home(self) -> tuple[Path, ...] | None:
         config_home = os.environ.get('XDG_CONFIG_HOME', USER_CONFIG_HOME)
 
         drc = Path(config_home) / DUQTOOLS_DIR
@@ -132,16 +142,16 @@ class VariableConfigLoader:
 
         return None
 
-    def _get_paths_fallback(self) -> Tuple[Path, ...]:
+    def _get_paths_fallback(self) -> tuple[Path, ...]:
         module = files('duqtools.data')
-        assert len(module._paths) == 1
-        drc = module._paths[0]
+        assert module.is_dir()
+        drc: PosixPath = module._paths[0]  # type: ignore
         return tuple(drc.glob(VAR_FILENAME_GLOB))
 
 
 def lookup_vars(
-    variables: Sequence[Union[str,
-                              IDSVariableModel]]) -> List[IDSVariableModel]:
+        variables: Sequence[(str | IDSVariableModel)]
+) -> list[IDSVariableModel]:
     """Helper function to look up a bunch of variables.
 
     If str, look up the variable from the `var_lookup`. Else, check if
@@ -150,7 +160,10 @@ def lookup_vars(
     var_models = []
     for var in variables:
         if isinstance(var, str):
-            var = var_lookup[var]
+            if var.endswith(ERROR_SUFFIX):
+                var = var_lookup.error_upper(var)
+            else:
+                var = var_lookup[var]
         if not isinstance(var, IDSVariableModel):
             raise ValueError(f'Cannot lookup variable with type {type(var)}')
         var_models.append(var)
