@@ -1,4 +1,5 @@
 import logging
+import os
 import shutil
 import warnings
 from pathlib import Path
@@ -63,12 +64,18 @@ class CreateManager:
 
         return ops_list
 
-    def make_run_models(self, ops_list: Sequence[Any]) -> list[Run]:
+    def make_run_models(self, ops_list: Sequence[Any],
+                        absolute_dirpath: bool) -> list[Run]:
         """Take list of operations and create run models."""
         run_models = []
 
         for i, operations in enumerate(ops_list):
-            dirname = self.runs_dir / f'{RUN_PREFIX}{i:04d}'
+            if absolute_dirpath:
+                dirname = self.runs_dir / f'{RUN_PREFIX}{i:04d}'
+            else:
+                dirname = Path(
+                    os.path.relpath(
+                        (self.runs_dir / f'{RUN_PREFIX}{i:04d}').resolve()))
 
             data_in = self.system.get_data_in_handle(
                 dirname=dirname,
@@ -84,7 +91,7 @@ class CreateManager:
                 options=self.options.data,
             )
 
-            model = Run(dirname=dirname.resolve(),
+            model = Run(dirname=dirname,
                         shortname=dirname.name,
                         data_in=data_in,
                         data_out=data_out,
@@ -207,7 +214,7 @@ class CreateManager:
                                           out=model.data_out)
 
 
-def create(*, force, config, **kwargs):
+def create(*, force, config, absolute_dirpath: bool = False, **kwargs):
     """Create input for jetto and IDS data structures.
 
     Parameters
@@ -224,7 +231,7 @@ def create(*, force, config, **kwargs):
 
     ops_list = create_mgr.generate_ops_list()
 
-    runs = create_mgr.make_run_models(ops_list)
+    runs = create_mgr.make_run_models(ops_list, absolute_dirpath)
 
     if not force:
 
