@@ -10,7 +10,7 @@ from typing import TYPE_CHECKING, Sequence
 
 from pydantic import validator
 
-from ..config import lookup_vars
+from ..config import lookup_vars, var_lookup
 from ..operations import add_to_op_queue
 from ..schema import IDSVariableModel, ImasBaseModel
 from ._copy import copy_ids_entry
@@ -221,6 +221,46 @@ class ImasHandle(ImasBaseModel):
         raw_data = self.get_raw_data(ids)
         return IDSMapping(raw_data)
 
+    def get_all_variables(
+        self,
+        extra_variables: Sequence[IDSVariableModel] = [],
+        squash: bool = True,
+        ids: str = 'core_profiles',
+        **kwargs,
+    ) -> xr.Dataset:
+        """Get all variables that duqtools knows of from selected ids from the
+        dataset.
+
+        This function looks up the data location from the
+        `duqtools.config.var_lookup` table
+
+        Parameters
+        ----------
+        variables : Sequence[IDSVariableModel]
+            Extra variables to load in addition to the ones known by duqtools.
+        squash : bool
+            Squash placeholder variables
+
+        Returns
+        -------
+        ds : xarray
+            The data in `xarray` format.
+        **kwargs
+            These keyword arguments are passed to `IDSMapping.to_xarray()`
+
+        Raises
+        ------
+        ValueError
+            When variables are from multiple IDSs.
+        """
+        idsvar_lookup = var_lookup.filter_ids(ids)
+        variables = list(
+            set(list(extra_variables) + list(idsvar_lookup.keys())))
+        return self.get_variables(variables,
+                                  squash,
+                                  empty_var_ok=True,
+                                  **kwargs)
+
     def get_variables(
         self,
         variables: Sequence[str | IDSVariableModel],
