@@ -3,7 +3,7 @@ import time
 from collections import deque
 from itertools import cycle
 from pathlib import Path
-from typing import Deque, List, Sequence
+from typing import Deque, Sequence
 
 from ._logging_utils import duqlog_screen
 from .config import cfg
@@ -25,18 +25,26 @@ def Spinner(frames='⠋⠙⠹⠸⠼⠴⠦⠧⠇⠏'):
 
 
 @add_to_op_queue('Submitting', '{job}')
-def _submit_job(job: Job):
+def _submit_job(job: Job, *, delay: float = 0):
+    """
+    Parameters
+    ----------
+    delay : float
+        Add a delay to avoid all jobs starting at the same time.
+        This causes issues with slurm, for example.
+    """
+    if delay:
+        time.sleep(delay)
     job.submit()
 
 
 def job_submitter(jobs: Sequence[Job], *, max_jobs):
     for n, job in enumerate(jobs):
-
         if max_jobs and (n >= max_jobs):
             info(f'Max jobs ({max_jobs}) reached.')
             break
 
-        _submit_job(job)
+        _submit_job(job, delay=0.1)
 
 
 @add_to_op_queue('Start job scheduler')
@@ -48,12 +56,14 @@ def job_scheduler(queue: Deque[Job], max_jobs=10):
     tasks: Deque[Job] = deque()
     completed: Deque[Job] = deque()
 
-    for _ in range(max_jobs):
-        job = queue.popleft()
-        task = job.start()
-        tasks.append(task)
+    while tasks or queue:
+        while queue and len(tasks) < max_jobs:
+            job = queue.popleft()
+            task = job.start()
+            tasks.append(task)
+            # starting jobs at the same time causes issues
+            time.sleep(0.1)
 
-    while tasks:
         time.sleep(interval)
         task = tasks.popleft()
         try:
@@ -62,11 +72,6 @@ def job_scheduler(queue: Deque[Job], max_jobs=10):
         except StopIteration:
             completed.append(task)
 
-        if queue and len(tasks) < max_jobs:
-            job = queue.popleft()
-            task = job.start()
-            tasks.append(task)
-
         print(
             f' {next(s)} Running: {len(tasks)},'
             f' queue: {len(queue)}, completed: {len(completed)}',
@@ -84,7 +89,11 @@ def job_array_submitter(jobs: Sequence[Job], *, max_jobs):
                      description='Adding to array',
                      extra_description=f'{job}')
 
-    get_system().submit_array(jobs)
+    if not max_jobs:
+        logger.info('Max jobs not specified, defaulting to 10')
+        max_jobs = 10
+
+    get_system().submit_array(jobs, max_jobs)
 
 
 def submission_script_ok(job):
@@ -124,7 +133,7 @@ def lockfile_ok(job, *, force):
     return True
 
 
-def get_resubmit_jobs(resubmit_names: Sequence[Path]) -> List[Job]:
+def get_resubmit_jobs(resubmit_names: Sequence[Path]) -> list[Job]:
     """get_resubmit_jobs.
 
     Parameters
@@ -134,9 +143,9 @@ def get_resubmit_jobs(resubmit_names: Sequence[Path]) -> List[Job]:
 
     Returns
     -------
-    List[Job]
+    list[Job]
     """
-    jobs: List[Job] = []
+    jobs: list[Job] = []
     run_dict = {run.shortname: run for run in Locations().runs}
     for name in resubmit_names:
         if name in run_dict:  # check for shortname
@@ -153,6 +162,7 @@ def submit(*,
            schedule: bool,
            array: bool,
            resubmit: Sequence[Path] = (),
+           status_filter: Sequence[str],
            **kwargs):
     """submit. Function which implements the functionality to submit jobs to
     the cluster.
@@ -172,6 +182,8 @@ def submit(*,
         If any jobs need to be resubmitted, this is has a nonzero length, and
         contains a Sequence of Paths which either are the full Path to the run
         that needs to be resubmitted, or the shortname
+    status_filter : list[str]
+        Only submit jobs with this status.
     """
     if not cfg.submit:
         raise SubmitError('Submit field required in config file')
@@ -189,6 +201,10 @@ def submit(*,
     job_queue: Deque[Job] = deque()
 
     for job in jobs:
+        status = job.status()
+
+        if status_filter and (status not in status_filter):
+            continue
         if not status_file_ok(job, force=force):
             continue
         if not lockfile_ok(job, force=force):
